[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![PyPI badge](http://img.shields.io/pypi/v/essreduce.svg)](https://pypi.python.org/pypi/essreduce)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/essreduce/badges/version.svg)](https://anaconda.org/conda-forge/essreduce)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)

# ESSreduce

## About

Common data reduction tools for the ESS facility

## Installation

```sh
python -m pip install essreduce
```
